﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Data;
using System.Data.SqlClient;

namespace PYRefresh
{
    public class DataUtils
    {
        #region Helper methods to access the database

        /// <summary>
        /// This this method to call a stored proc and return a dataset
        /// </summary>
        /// <param name="connStr"></param>
        /// <param name="sCommand"></param>
        /// <param name="CmdType"></param>
        /// <param name="oParameters"></param>
        /// <returns></returns>
        public static DataSet GetDataSet(string connStr, string sCommand, CommandType CmdType, ref SqlParameter[] oParameters)
        {
            SqlConnection conn = new SqlConnection(connStr);

            SqlCommand cmdToExecute = null;
            SqlDataAdapter adap = null;

            DataSet oDS = new DataSet();

            try
            {
                cmdToExecute = new SqlCommand(sCommand, conn);
                cmdToExecute.CommandType = CmdType;
                cmdToExecute.CommandTimeout = 300;
                if ((oParameters != null))
                {
                    foreach (var p in oParameters)
                    {
                        if ((!object.ReferenceEquals(p.Value, System.DBNull.Value)))
                        {
                            //If the parameter value is set to dbnull don't add the parameter. 
                            cmdToExecute.Parameters.Add(p);

                        }
                    }
                }
                adap = new SqlDataAdapter(cmdToExecute);
                adap.Fill(oDS);

                return oDS;
            }
            catch (Exception ex)
            {
                throw new Exception("GetDataSet failed " + ex.Message);
            }
            finally
            {
                if ((cmdToExecute != null)) cmdToExecute.Dispose();
                if ((adap != null)) adap.Dispose();
                conn.Close();
            }
        }

        public static DataSet GetDataSet(string connStr, string sCommand, CommandType CmdType)
        {
            SqlConnection conn = new SqlConnection(connStr);

            SqlCommand cmdToExecute = null;
            SqlDataAdapter adap = null;

            DataSet oDS = new DataSet();

            try
            {
                cmdToExecute = new SqlCommand(sCommand, conn);
                cmdToExecute.CommandType = CmdType;
                cmdToExecute.CommandTimeout = 300;
                adap = new SqlDataAdapter(cmdToExecute);
                adap.Fill(oDS);

                return oDS;
            }
            catch (Exception ex)
            {
                throw new Exception("GetDataSet failed " + ex.Message);
            }
            finally
            {
                if ((cmdToExecute != null)) cmdToExecute.Dispose();
                if ((adap != null)) adap.Dispose();
                conn.Close();
            }
        }
        public static void GetExecNonQry(string connStr, string sCommand, CommandType CmdType)
        {
            SqlConnection conn = new SqlConnection(connStr);

            SqlCommand cmdToExecute = null;

            try
            {
                conn.Open();
                cmdToExecute = new SqlCommand(sCommand, conn);
                cmdToExecute.CommandType = CmdType;
                cmdToExecute.CommandTimeout = 300;

                cmdToExecute.ExecuteNonQuery();

            }
            catch (Exception ex)
            {
                throw new Exception("GetExecNonQty failed " + ex.Message);
            }
            finally
            {
                if ((cmdToExecute != null)) cmdToExecute.Dispose();
                conn.Close();
            }
        }
        /// <summary>
        /// Use this method to call a stored proc and execute it no data returned
        /// </summary>
        /// <param name="connStr"></param>
        /// <param name="sCommand"></param>
        /// <param name="CmdType"></param>
        /// <param name="oParameters"></param>
        public static void GetExecNonQry(string connStr, string sCommand, CommandType CmdType, ref SqlParameter[] oParameters)
        {
            SqlConnection conn = new SqlConnection(connStr);

            SqlCommand cmdToExecute = null;

            try
            {
                conn.Open();
                cmdToExecute = new SqlCommand(sCommand, conn);
                cmdToExecute.CommandType = CmdType;
                cmdToExecute.CommandTimeout = 300;
                if ((oParameters != null))
                {
                    foreach (var p in oParameters)
                    {
                        if ((!object.ReferenceEquals(p.Value, System.DBNull.Value)))
                        {
                            //If the parameter value is set to dbnull don't add the parameter. 
                            cmdToExecute.Parameters.Add(p);

                        }
                    }
                }
                cmdToExecute.ExecuteNonQuery();

            }
            catch (Exception ex)
            {
                throw new Exception("GetExecNonQty failed " + ex.Message);
            }
            finally
            {
                if ((cmdToExecute != null)) cmdToExecute.Dispose();
                conn.Close();
            }
        }

        public static object GetExecScalar(string connStr, string sCommand, CommandType CmdType, ref SqlParameter[] oParameters)
        {
            SqlConnection conn = new SqlConnection(connStr);

            SqlCommand cmdToExecute = null;

            try
            {
                conn.Open();
                cmdToExecute = new SqlCommand(sCommand, conn);
                cmdToExecute.CommandType = CmdType;
                cmdToExecute.CommandTimeout = 300;
                if ((oParameters != null))
                {
                    foreach (var p in oParameters)
                    {
                        if ((!object.ReferenceEquals(p.Value, System.DBNull.Value)))
                        {
                            //If the parameter value is set to dbnull don't add the parameter. 
                            cmdToExecute.Parameters.Add(p);

                        }
                    }
                }
                return cmdToExecute.ExecuteScalar();

            }
            catch (Exception ex)
            {
                throw new Exception("GetExecScalar failed " + ex.Message);
            }
            finally
            {
                if ((cmdToExecute != null)) cmdToExecute.Dispose();
                conn.Close();
            }
        }
        #endregion
    }
}